@@ -90,22 +90,27 @@ class Parameter:
     name: Optional[str]
     type: Optional[Type]
     help: str = ''
-    children: List['Parameter'] = dataclasses.field(default_factory=list)
+    children: List['Parameter'] = dataclasses.field(default_factory=list, repr=False)
     default_factory: Optional[Callable[[], Any]] = None
     choices: Optional[List[Any]] = None
     argument_type: Optional[Any] = None
     _argument_name: Optional[Tuple[str]] = None
 
-    def walk(self, fn: Callable[['ParameterWithPath', List[Any]], Any]):
+    def walk(self, fn: Callable[['ParameterWithPath', List[Any]], Any], reverse: bool = False):
         def _walk(e, parent):
             e = ParameterWithPath(e, parent)
             new_children = []
-            for p in e.children:
+            children = e.children
+            if reverse:
+                children = reversed(children)
+            for p in children:
                 result = _walk(p, e)
                 if result is not None:
                     if isinstance(result, ParameterWithPath):
                         result = result.parameter
                     new_children.append(result)
+            if reverse:
+                new_children = list(reversed(new_children))
             return fn(e, children=new_children)
         result = _walk(self, None)
         if isinstance(result, ParameterWithPath):
@@ -142,7 +147,7 @@ class Parameter:
 @dataclasses.dataclass
 class ParameterWithPath:
     parameter: Parameter
-    parent: Optional['ParameterWithPath'] = None
+    parent: Optional['ParameterWithPath'] = dataclasses.field(repr=False, default=None)
 
     @property
     def name(self):
@@ -298,6 +303,13 @@ def WithArgumentName(cls, name=None):
     return new_type
 
 
+def FunctionConditionalType(switch: Callable[[Dict[str, str]], Type], prefix: bool = True):
+    tp = typing.NewType('FunctionConditionalType', Callable[[Dict[str, str]], Type])
+    setattr(tp, '__conditional_fmap__', switch)
+    setattr(tp, '__conditional_prefix__', prefix)
+    return tp
+
+
 def _forward_parameters(fn, outer_args, outer_kwargs, skip_first=False):
     def _fn(*args, **kwargs):
         kwargs = dict(**kwargs)
